<?php
# dvdisaster: German homepage dictionary
# Copyright (C) 2004-2012 Carsten Gnörlich
#
# UTF-8 trigger: äöüß 

# German dictionary for some phrases used in dvdisaster.php

$trans_version="Version";

$trans_to_internet="Zur Internet-Version";
$trans_to_hoster="Übersicht (auf SourceForge.net)";

$trans_back="Zurück";
$trans_screen_shot="Bildschirmfoto";

$trans_contents="Inhalt";
$trans_news="Neuigkeiten";
$trans_atom_title="Neues von dvdisaster";
$trans_hosting="Diese Seiten liegen auf";

$trans_fdl="Die unveränderte Wiedergabe und Verteilung dieses gesamten Textes in beliebiger Form ist gestattet, sofern dieser Hinweis erhalten bleibt.";
$trans_copyright="Copyright 2004-2012 Carsten Gnörlich.";

$trans_sourcecode="Quellkode für alle Betriebssysteme:";
$trans_signature="Digitale Unterschrift:";
$trans_md5="MD5-Prüfsumme:";
$trans_macbinary="Binärversion für Mac OS X 10.5 / x86:";
$trans_winbinary="Binärversion für Windows:";
?>